"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path_1 = require("path");
var sequelize_1 = require("sequelize");
var DataBaseModel = /** @class */ (function () {
    function DataBaseModel(config) {
        this.name = config.database;
        this.db = {};
        this.db.associate = this.associate;
        this.sequelize = new sequelize_1.Sequelize(config.database, config.user, config.password, {
            host: config.host,
            port: config.port,
            dialect: config.dialect || "mysql",
            pool: config.pool || {
                max: 10,
                min: 2,
                idle: 10000
            },
            define: {
                timestamps: config.timestamps || false
            },
            logging: false //config.log || console.log
        });
        try {
            this.sequelize.authenticate();
        }
        catch (error) {
            console.error("Unable to connect to the database:", error);
        }
        this.sequelize.dialect.supports.schemas = true;
    }
    DataBaseModel.prototype.dir = function (path) {
        return this.modelPath(path);
    };
    DataBaseModel.prototype.modelPath = function (p) {
        var _this = this;
        var files = fs.readdirSync(p)
            .filter(function (file) {
            return (file.indexOf(".") !== 0) &&
                (file !== "index.js") &&
                (!fs.lstatSync(path_1.join(p, file)).isDirectory()) &&
                (file.indexOf(".map") <= 0);
        })
            .forEach(function (file) {
            var model = _this.sequelize.import(path_1.join(p, file));
            _this.db[model.name] = model;
        });
        this.db.sequelize = this.sequelize;
        this.db.Sequelize = sequelize_1.Sequelize;
        return this.db;
    };
    DataBaseModel.prototype.associate = function (db, relatives) {
        Object.keys(db).forEach(function (modelName) {
            if ("associate" in db[modelName]) {
                db[modelName].associate(db, relatives);
            }
        });
        return db;
    };
    return DataBaseModel;
}());
exports.default = DataBaseModel;
